@@ -22,7 +22,11 @@ def modules(target, arg):
     for name, mod in sorted(modules.items()):
         hlp = mod.help()
         first = hlp.split('\n')[0]
-        print(f'{name:>{width}} {first}')
+        if (
+            not arg
+            or arg in name
+            or arg in first.lower()
+        ): print(f'{name:>{width}} {first}')
 
 def deploy(target, arg):
     target.deploy(arg)
